sqlite_hook — Airflow Documentation

# Source code for sqlite_hook

    # -*- coding: utf-8 -*-
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing, software
    # distributed under the License is distributed on an "AS IS" BASIS,
    # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    # See the License for the specific language governing permissions and
    # limitations under the License.

    import sqlite3

    from airflow.hooks.dbapi_hook import DbApiHook

    class SqliteHook(DbApiHook):

        """
        Interact with SQLite.
        """

        conn_name_attr = 'sqlite_conn_id'
        default_conn_name = 'sqlite_default'
        supports_autocommit = False

        def get_conn(self):
            """
            Returns a sqlite connection object
            """
            conn = self.get_connection(self.sqlite_conn_id)
            conn = sqlite3.connect(conn.host)
            return conn